@@ -135,7 +135,7 @@ def _add_backoff(f):
 
 
 @_add_backoff
-def _json_POST(end_point, payload):
+def _json_POST(end_point: str, payload: dict):
     url = _SESSION_STUFF["api_url_base"].format(end_point)
     logger.debug(f"posting to {url}, {payload}")
 
@@ -155,7 +155,7 @@ def _json_POST(end_point, payload):
 
 
 @_add_backoff
-def _json_GET(path, params):
+def _json_GET(path: str, params: dict = {}):
     url = _SESSION_STUFF["domain"].format(path)
     response = _calcbench_session().get(
         url,
@@ -853,13 +853,6 @@ def disclosure_text(network_id):
     return r.json()
 
 
-def available_metrics():
-    url = _SESSION_STUFF["api_url_base"].format("availableMetrics")
-    r = _calcbench_session().get(url, verify=_SESSION_STUFF["ssl_verify"])
-    r.raise_for_status()
-    return r.json()
-
-
 def business_combinations(company_identifiers):
     payload = {
         "companiesParameters": {"companyIdentifiers": company_identifiers},
